# Project Contributors

The following people have made contributions to this project:

- [Gionata Ghiggi (ghiggi)](https://github.com/ghiggi) - EPFL
- [Marti Bosch (martibosch)](https://github.com/martibosch) - EPFL
